#include <stdint.h>
#include "r_meter.h"

//sbits
sbit S1             at LATD0_bit;
sbit S1_DIR         at TRISD0_bit;
sbit S2             at LATE8_bit;
sbit S2_DIR         at TRISE8_bit;
sbit S3             at LATC1_bit;
sbit S3_DIR         at TRISC1_bit;
sbit R_METER_CS     at LATC2_bit;
sbit R_METER_CS_DIR at TRISC2_bit;

//Prototypes
void system_setup( void );

//Main
void main()
{
    //Local Declarations
    char txt[20] = { 0 };
    float ohms_var = 0;

    //Setup
    system_setup();

    while (1)
    {
        ohms_var = r_meter_get_ohms();
        if( ohms_var == 0 )
            UART1_Write_Text( "Over Range\r\n" );
        else
        {
            FloatToStr( ohms_var, txt );
            UART1_Write_Text( "OHMS: " );
            UART1_Write_Text( txt );
            UART1_Write_Text( "\r\n" );
        }
        delay_ms(250);
    }
}

void system_setup( void )
{
    //SPI Clock
    PLLFBD = 70;             // PLL multiplier M=70
    CLKDIV = 0x0000;         // PLL prescaler N1=2, PLL postscaler N2=2
    //Analog settings
    ANSELA = 0x00;           // Convert all I/O pins to digital
    ANSELB = 0x00;
    ANSELC = 0x00;
    ANSELD = 0x00;
    ANSELE = 0x00;
    //UART remapping
    PPS_Mapping(100, _INPUT,  _U1RX);              // Sets pin RP100 to be Input, and maps U1RX to it
    PPS_Mapping(101, _OUTPUT, _U1TX);              // Sets pin RP101 to be Output, and maps U1TX to it
    // GPIOs
    S1_DIR = 0;
    S2_DIR = 0;
    S3_DIR = 0;
    R_METER_CS_DIR = 0;
    //SPI Remapping
    PPS_Mapping(104, _OUTPUT,  _SDO3);             // Sets pin RP104 to be Output, and maps SD03 to it
    PPS_Mapping(98, _INPUT, _SDI3);                // Sets pin RP98 to be Input, and maps SD01 to it
    PPS_Mapping(79, _OUTPUT, _SCK3OUT);            // Sets pin RP79 to be Output, and maps SCK3 to it
    // Setting output frequency to 140MHz
    Delay_ms(100);
    // SPI
    SPI3_Init_Advanced(_SPI_MASTER,
                     _SPI_8_BIT,
                     _SPI_PRESCALE_SEC_4,
                     _SPI_PRESCALE_PRI_16,
                     _SPI_SS_DISABLE,
                     _SPI_DATA_SAMPLE_END,
                     _SPI_CLK_IDLE_LOW,
                     _SPI_IDLE_2_ACTIVE);
    Delay_ms( 200 );
    //UART
    UART1_Init(9600);                      // Initialize UART module at 9600 bps
    Delay_ms(300);                         // Wait for UART module to stabilize
    UART1_Write_Text( "UART Initialized\r\n" );
    UART1_Write_Text( "SPI Initialized\r\n" );
    //R Meter initialization
    r_meter_init();
    UART1_Write_Text( "R Meter Initialized\r\n" );
}